@@ -13,8 +13,7 @@ use Fcntl;
 use Carp qw/croak/;
 
 ## no critic (constant)
-
-our $VERSION = '1.007';
+our $VERSION = '1.008';
 use constant UINT32_SIZE => 4;
 
 sub new {
@@ -24,8 +23,7 @@ sub new {
         = defined $params{nonblocking} ? $params{nonblocking} : 1;
     my $self = {};
     my @methodlist
-        = ( \&_try_win32, \&_try_egd, \&_try_dev_random, \&_try_dev_urandom );
-
+        = ( \&_try_win32, \&_try_dev_random, \&_try_dev_urandom );
     foreach my $m (@methodlist) {
         my ($name, $rsub, $isblocking, $isstrong) = $m->();
         next unless defined $name;
@@ -77,13 +75,11 @@ sub _try_win32 {
     return unless $^O eq 'MSWin32';
     eval { require Win32; require Win32::API; require Win32::API::Type; 1; }
         or return;
-
     use constant CRYPT_SILENT      => 0x40;       # Never display a UI.
     use constant PROV_RSA_FULL     => 1;          # Which service provider.
     use constant VERIFY_CONTEXT    => 0xF0000000; # Don't need existing keepairs
     use constant W2K_MAJOR_VERSION => 5;          # Windows 2000
     use constant W2K_MINOR_VERSION => 0;
-
     my ($major, $minor) = (Win32::GetOSVersion())[1, 2];
     return if $major < W2K_MAJOR_VERSION;
 
@@ -129,56 +125,6 @@ _RTLGENRANDOM_PROTO_
     return;
 }
 
-sub _try_egd {
-    my @devices
-        = qw(/var/run/egd-pool /dev/egd-pool /etc/egd-pool /etc/entropy);
-    foreach my $device (@devices) {
-        next unless -r $device && -S $device;
-        eval { require IO::Socket; 1; } or return;
-        my $socket = IO::Socket::UNIX->new(Peer => $device, Timeout => 1);
-        next unless $socket;
-        $socket->syswrite( pack("C", 0x00), 1) or next;
-        die if $socket->error;
-        my($entropy_string, $nread);
-        eval {
-            local $SIG{ALRM} = sub { die "alarm\n" };
-            alarm 1;
-            $nread = $socket->sysread($entropy_string, 4);
-            alarm 0;
-        };
-        if ($@) {
-            die unless $@ eq "alarm\n";
-            next;
-        }
-        next unless defined $nread && $nread == 4;
-        my $entropy_avail = unpack("N", $entropy_string);
-        return ('EGD', sub { __read_egd($device, @_); }, 1, 1);
-    }
-    return;
-}
-
-sub __read_egd {
-    my ($device, $nbytes) = @_;
-    return unless defined $device;
-    return unless defined $nbytes && int($nbytes) > 0;
-    croak "$device doesn't exist!" unless -r $device && -S $device;
-    my $socket = IO::Socket::UNIX->new(Peer => $device);
-    croak "Can't talk to EGD on $device. $!" unless $socket;
-    my($s, $buffer, $toread) = ('', '', $nbytes);
-    while ($toread > 0) {
-        my $this_request = ($toread > 255) ? 255 : $toread;
-        $socket->syswrite( pack("CC", 0x02, $this_request), 2);
-        my $this_grant = $socket->sysread($buffer, $this_request);
-        croak "Error reading EDG data from $device: $!\n"
-            unless defined $this_grant && $this_grant == $this_request;
-        $s .= $buffer;
-        $toread -= length($buffer);
-    }
-    croak "Internal EGD read error: wanted $nbytes, read ", length($s), ""
-        unless $nbytes == length($s);  # assert
-    return $s;
-}
-
 1;
 
 # Math::Random::ISAAC::PP::Embedded: Adapted from  #
@@ -191,7 +137,7 @@ package Math::Random::ISAAC::PP::Embedded;
 use strict;
 use warnings;
 
-our $VERSION = '1.007';
+our $VERSION = '1.008';
 use constant {
     randrsl => 0, randcnt => 1, randmem => 2,
     randa   => 3, randb   => 4, randc   => 5,
@@ -201,12 +147,9 @@ sub new {
     my ($class, @seed) = @_;
     my $seedsize = scalar(@seed);
     my @mm;
-
     $#mm = $#seed = 255;                # predeclare arrays with 256 slots
     $seed[$_] = 0 for $seedsize .. 255; # Zero-fill unused seed space.
-
     my $self = [ \@seed, 0, \@mm, 0, 0, 0 ];
-
     bless $self, $class;
     $self->_randinit;
     return $self;
@@ -226,11 +169,9 @@ sub irand {
 sub _isaac {
     my $self = shift;
     use integer;
-
     my($mm, $r, $aa) = @{$self}[randmem,randrsl,randa];
     my $bb = ($self->[randb] + (++$self->[randc])) & 0xffffffff;
     my ($x, $y); # temporary storage
-
     for (my $i = 0; $i < 256; $i += 4) {
         $x = $mm->[$i  ];
         $aa = (($aa ^ ($aa << 13)) + $mm->[($i   + 128) & 0xff]);
@@ -256,7 +197,6 @@ sub _isaac {
         $mm->[$i+3] = $y = ($mm->[($x >> 2) & 0xff] + $aa + $bb) & 0xffffffff;
         $r->[$i+3] = $bb = ($mm->[($y >> 10) & 0xff] + $x) & 0xffffffff;
     }
-
     @{$self}[randb, randa] = ($bb,$aa);
     return;
 }
@@ -264,10 +204,8 @@ sub _isaac {
 sub _randinit {
     my $self = shift;
     use integer;
-
     my ($c, $d, $e, $f, $g, $h, $j, $k) = (0x9e3779b9)x8; # The golden ratio.
     my ($mm, $r) = @{$self}[randmem,randrsl];
-
     for (1..4) {
         $c ^= $d << 11;                     $f += $c;       $d += $e;
         $d ^= 0x3fffffff & ($e >> 2);       $g += $d;       $e += $f;
@@ -278,13 +216,11 @@ sub _randinit {
         $j ^= $k << 8;                      $d += $j;       $k += $c;
         $k ^= 0x007fffff & ($c >> 9);       $e += $k;       $c += $d;
     }
-
     for (my $i = 0; $i < 256; $i += 8) {
         $c += $r->[$i  ];   $d += $r->[$i+1];
         $e += $r->[$i+2];   $f += $r->[$i+3];
         $g += $r->[$i+4];   $h += $r->[$i+5];
         $j += $r->[$i+6];   $k += $r->[$i+7];
-
         $c ^= $d << 11;                     $f += $c;       $d += $e;
         $d ^= 0x3fffffff & ($e >> 2);       $g += $d;       $e += $f;
         $e ^= $f << 8;                      $h += $e;       $f += $g;
@@ -293,19 +229,16 @@ sub _randinit {
         $h ^= 0x0fffffff & ($j >> 4);       $c += $h;       $j += $k;
         $j ^= $k << 8;                      $d += $j;       $k += $c;
         $k ^= 0x007fffff & ($c >> 9);       $e += $k;       $c += $d;
-
         $mm->[$i  ] = $c;   $mm->[$i+1] = $d;
         $mm->[$i+2] = $e;   $mm->[$i+3] = $f;
         $mm->[$i+4] = $g;   $mm->[$i+5] = $h;
         $mm->[$i+6] = $j;   $mm->[$i+7] = $k;
     }
-
     for (my $i = 0; $i < 256; $i += 8) {
         $c += $mm->[$i  ];  $d += $mm->[$i+1];
         $e += $mm->[$i+2];  $f += $mm->[$i+3];
         $g += $mm->[$i+4];  $h += $mm->[$i+5];
         $j += $mm->[$i+6];  $k += $mm->[$i+7];
-
         $c ^= $d << 11;                     $f += $c;       $d += $e;
         $d ^= 0x3fffffff & ($e >> 2);       $g += $d;       $e += $f;
         $e ^= $f << 8;                      $h += $e;       $f += $g;
@@ -314,13 +247,11 @@ sub _randinit {
         $h ^= 0x0fffffff & ($j >> 4);       $c += $h;       $j += $k;
         $j ^= $k << 8;                      $d += $j;       $k += $c;
         $k ^= 0x007fffff & ($c >> 9);       $e += $k;       $c += $d;
-
         $mm->[$i  ] = $c;   $mm->[$i+1] = $d;
         $mm->[$i+2] = $e;   $mm->[$i+3] = $f;
         $mm->[$i+4] = $g;   $mm->[$i+5] = $h;
         $mm->[$i+6] = $j;   $mm->[$i+7] = $k;
     }
-
     $self->_isaac;
     $self->[randcnt] = 256;
     return;
@@ -333,7 +264,7 @@ package Math::Random::ISAAC::Embedded;
 use strict;
 use warnings;
 
-our $VERSION = '1.007';
+our $VERSION = '1.008';
 use constant _backend => 0;
 
 my %CSPRNG = (
@@ -367,7 +298,7 @@ use 5.006000;
 use Carp qw(croak);
 use Hash::Util;
 
-our $VERSION = '1.007';
+our $VERSION = '1.008';
 
 # See Math::Random::ISAAC https://rt.cpan.org/Public/Bug/Display.html?id=64324
 use constant SEED_SIZE => 256; # bits; eight 32-bit words.
@@ -422,6 +353,7 @@ sub string_from {
 sub shuffle {
     my($self, $aref) = @_;
     croak 'Argument must be an array reference.' unless 'ARRAY' eq ref $aref;
+    return $aref unless @$aref;
     for (my $i = @$aref; --$i;) {
         my $r = $self->_ranged_randoms($i+1, 1)->[0];
         ($aref->[$i],$aref->[$r]) = ($aref->[$r], $aref->[$i]);
@@ -433,7 +365,6 @@ sub _ranged_randoms {
     my ($self, $range, $count) = @_;
     $_ = defined $_ ? $_ : 0 for $count, $range;
     croak "$range exceeds irand max limit of 2^^32." if $range > 2**32;
-
     # Find nearest factor of 2**32 >= $range.
     my $divisor = do {
         my ($n, $d) = (0,0);
@@ -442,7 +373,6 @@ sub _ranged_randoms {
     };
     my @randoms;
     $#randoms = $count-1; @randoms = (); # Microoptimize: Preextend & purge.
-
     for my $n (1 .. $count) { # re-roll if r-num is out of bag range (modbias)
         my $rand = $self->irand % $divisor;
         $rand    = $self->irand % $divisor while $rand >= $range;
